#' Configuration for new projects
#'
#' This list stores the configuration used for new projects.
#'
#' @include translate.dcf.R
new.config <- translate.dcf(system.file('defaults/full/config/global.dcf', package = 'ProjectTemplate'))
